@@ -3,7 +3,7 @@ from pathlib import Path as path
 
 
 class GCPConfig:
-    BUCKET = "signals-data"
+    BUCKET = os.environ.get('BUCKET_NAME', "signals-data")
     WORKER_PREFIX = os.environ.get('WORKER_PREFIX', 'cc-')
     MAX_INSTANCE_RESTART = os.environ.get('MAX_INSTANCE_RESTART', 5)
     IP_BLOCK_SECONDS = os.environ.get('IP_BLOCK_SECONDS', 100000)
